@@ -26,6 +26,7 @@ class bcolors:
     UNDERLINE = '\033[4m'
 
 class GrantedConsole(code.InteractiveConsole):
+    
     def push(self, line):
         """Push a line to the interpreter.
 
@@ -46,7 +47,7 @@ class GrantedConsole(code.InteractiveConsole):
             url=url,
             json={"data": {"command": line}},
             headers={
-                "X-Granted-Request": token,
+                "X-Granted-Request": os.environ["TOKEN"],
                 "Content-Type": "application/json",
             },
         )
@@ -111,7 +112,7 @@ def interact(banner=None, readfunc=None, local=None, exitmsg=None):
             url=url,
             
             headers={
-                "X-Granted-Request": token,
+                "X-CommonFate-Access-Token": token,
                 "Content-Type": "application/json",
             },
         )
@@ -123,6 +124,20 @@ def interact(banner=None, readfunc=None, local=None, exitmsg=None):
             retry = False
         
     print('Correct token, entering Flask shell...\n')
+
+    #set the token in the environment to be used later
+    os.environ["TOKEN"] = token
+
+    url = base_url + "/events-recorder"
+    res = requests.post(
+        url=url,
+        json={"data": {"action": "Entered Shell"}},
+        headers={
+            "X-CommonFate-Access-Token": os.environ["TOKEN"],
+            "Content-Type": "application/json",
+        },
+    )
+
     console.interact(banner, exitmsg)
 
 
@@ -176,32 +191,3 @@ def shell_command():
 
     interact(banner=banner, local=ctx)
 
-@click.command('test', short_help='Runs tests against Granted Cloud to check setup has been successfully complete')
-@with_appcontext
-def test_command():
-    """
-
-    """
-    print('Testing Webhook URL set...\n')
-    if 'GRANTED_WEBHOOK_URL' not in os.environ:
-        print('GRANTED_WEBHOOK_URL (Granted deployment URL) is not set, if you are seeing this contact your administrator.')
-        
-        return
-    else:
-        print('Testing URL connection...\n')
-        base_url = os.environ['GRANTED_WEBHOOK_URL']
-        url = base_url + "/test-setup"
-        x = requests.post(
-            url=url,
-            
-            headers={
-                # "X-Granted-Request": token,
-                "Content-Type": "application/json",
-            },
-        )
-    
-        if x.status_code != 200:
-            print(bcolors.FAIL +'Failed to connect to Granted webhook. Have you setup your Granted Flask provider with a correct webhook url?'+ bcolors.ENDC)
-            
-        else:
-            print(bcolors.OKGREEN +'Setup Success!'+ bcolors.ENDC)
\ No newline at end of file
